[cl-plus-ssl-cvs] CVS trivial-gray-streams

hhubner hhubner at common-lisp.net
Wed Sep 10 16:36:29 UTC 2008


Update of /project/cl-plus-ssl/cvsroot/trivial-gray-streams
In directory clnet:/home/hhubner/trivial-gray-streams

Modified Files:
	mixin.lisp package.lisp 
Log Message:
Commit ECL patch submitted by Geo Carncross


--- /project/cl-plus-ssl/cvsroot/trivial-gray-streams/mixin.lisp	2006/09/14 17:45:36	1.5
+++ /project/cl-plus-ssl/cvsroot/trivial-gray-streams/mixin.lisp	2008/09/10 16:36:29	1.6
@@ -115,3 +115,12 @@
   ;; SBCL extension:
   (defmethod sb-gray:stream-line-length ((stream trivial-gray-stream-mixin))
     80))
+
+#+ecl
+(progn
+  (defmethod gray:stream-read-sequence
+    ((s trivial-gray-stream-mixin) seq &optional start end)
+    (stream-read-sequence s seq (or start 0) (or end (length seq))))
+  (defmethod gray:stream-write-sequence
+    ((s trivial-gray-stream-mixin) seq &optional start end)
+    (stream-write-sequence s seq (or start 0) (or end (length seq)))))
--- /project/cl-plus-ssl/cvsroot/trivial-gray-streams/package.lisp	2006/09/14 17:45:36	1.4
+++ /project/cl-plus-ssl/cvsroot/trivial-gray-streams/package.lisp	2008/09/10 16:36:29	1.5
@@ -9,6 +9,10 @@
   (unless (fboundp 'stream:stream-write-string)
     (require "streamc.fasl")))
 
+#+ecl
+(eval-when (:compile-toplevel :load-toplevel :execute)
+  (gray::redefine-cl-functions))
+
 (macrolet
     ((frob ()
        (let
@@ -34,7 +38,8 @@
 			  #+clisp :gray
 			  #+openmcl :ccl
 			  #+lispworks :stream
 			  #-(or sbcl allegro cmu clisp openmcl lispworks) ...
 			  , at common-symbols)
 	    (:export #:trivial-gray-stream-mixin
 		     #:stream-read-sequence
@@ -34,7 +38,8 @@
 			  #+openmcl :ccl
 			  #+lispworks :stream
-			  #-(or sbcl allegro cmu clisp openmcl lispworks) ...
+			  #+ecl :gray
+			  #-(or sbcl allegro cmu clisp openmcl lispworks ecl) ...
 			  , at common-symbols)
 	    (:export #:trivial-gray-stream-mixin




More information about the cl-plus-ssl-cvs mailing list